From: David Turner Date: Mon, 21 Dec 2015 23:33:04 GMT Subject: Re: [PATCH v2 0/2] do_compare_entry: use already-computed path Message-ID: <1450740784.3892.3.camel@twopensource.com> In-Reply-To: On Mon, 2015-12-21 at 15:27 -0800, Junio C Hamano wrote: > Thanks. Does the number still stay at 25% improvement? Yes.